(* File lexer.mll *)
{
  open Parser        (* The type token is defined in parser.mli *)
  exception Eof

  let h = Hashtbl.create 4
  let _ =
    List.iter (fun (k,t) -> Hashtbl.add h k t)
      [("+",ADD); ("-",MIN); ("*",MUL); ("/",DIV); ("=",EQ)]

}
let ident = ['a'-'z' 'A'-'Z' '_']['a'-'z' 'A'-'Z' '_' '0'-'9']*

let white = [' ' '\t' '\n']

let num = '-'?['0'-'9']['0'-'9']*

let flt = '-'?['0'-'9']['0'-'9']*'.'['0'-'9']*

let op = ['+''-''*''/''=']

rule token = parse
  | white+         { token lexbuf }     (* skip blanks *)
  | num  as n      { INT (int_of_string n) }
  | flt  as f      { FLT (float_of_string f) }
  | "let"          { LET }
  | "in"           { IN }
  | ident as ato   { VAR ato }
  | op             { Hashtbl.find h (Lexing.lexeme lexbuf)}
  | '('            { LPAREN }
  | ')'            { RPAREN }
  | eof            { EOF }
